==> libksieve-21.04.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5LibKSieve/KF5LibKSieveTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KManageSieve" for configuration ""
set_property(TARGET KF5::KManageSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KManageSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::KIOCore;KF5::KIOWidgets"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.5.17.1"
  IMPORTED_SONAME_NOCONFIG "libKF5KManageSieve.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KManageSieve )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KManageSieve "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.5.17.1" )

# Import target "KF5::KSieveUi" for configuration ""
set_property(TARGET KF5::KSieveUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KSieveUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::Libkdepim;KF5::Archive;KF5::Mime;KF5::IconThemes;KF5::IdentityManagement;KF5::MailTransport;KF5::KIOWidgets;KF5::NewStuff;Qt5::WebEngineWidgets;KF5::PimTextEdit;KF5::I18n;KF5::SonnetUi;Qt5::PrintSupport;KF5::SyntaxHighlighting"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.17.1"
  IMPORTED_SONAME_NOCONFIG "libKF5KSieveUi.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KSieveUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KSieveUi "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.17.1" )

# Import target "KF5::KSieve" for configuration ""
set_property(TARGET KF5::KSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Core;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.5.17.1"
  IMPORTED_SONAME_NOCONFIG "libKF5KSieve.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KSieve )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KSieve "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.5.17.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libksieve-21.08.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5LibKSieve/KF5LibKSieveTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KManageSieve" for configuration ""
set_property(TARGET KF5::KManageSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KManageSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::KIOCore;KF5::KIOWidgets"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.5.18.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KManageSieve.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KManageSieve )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KManageSieve "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.5.18.0" )

# Import target "KF5::KSieveUi" for configuration ""
set_property(TARGET KF5::KSieveUi APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KSieveUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::Libkdepim;KF5::Archive;KF5::Mime;KF5::IconThemes;KF5::IdentityManagement;KF5::MailTransport;KF5::KIOWidgets;KF5::NewStuff;KF5::PimTextEdit;KF5::I18n;KF5::SonnetUi;KF5::SyntaxHighlighting"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.18.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KSieveUi.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KSieveUi )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KSieveUi "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.18.0" )

# Import target "KF5::KSieve" for configuration ""
set_property(TARGET KF5::KSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.5.18.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KSieve.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KSieve )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KSieve "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.5.18.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
